@@ -1,4 +1,4 @@
-//$Id: main.cc,v 1.2 2002/05/20 19:21:55 daniel Exp $ -*- c++ -*-
+//$Id: main.cc 449 2005-11-16 20:22:00Z  $ -*- c++ -*-
 
 /* gtkmm example Copyright (C) 2002 gtkmm development team
  *
@@ -25,12 +25,13 @@ int main(int argc, char** argv)
    Gtk::Main kit(argc, argv);
 
    Gtk::Window win;
+   win.set_title("DrawingArea");
 
    MyArea area;
    win.add(area);
    area.show();
 
-   kit.run(win);
+   Gtk::Main::run(win);
 
    return 0;
 }
