@@ -1,4 +1,4 @@
-//$Id: main.cc,v 1.1.1.1 2003/01/21 13:41:35 murrayc Exp $ -*- c++ -*-
+//$Id: main.cc 449 2005-11-16 20:22:00Z  $ -*- c++ -*-
 
 /* gtkmm example Copyright (C) 2002 gtkmm development team
  *
@@ -26,7 +26,7 @@ int main(int, char**)
   Client client;
 
   //Connect a Server signal to the signal handler in Client.
-  server.signal_something().connect( SigC::slot(client, &Client::on_server_something) );
+  server.signal_something().connect( sigc::mem_fun(client, &Client::on_server_something) );
 
   std::cout << "Before Server::do_something()" << std::endl;
 
