@@ -1,4 +1,4 @@
-//$Id: server.h,v 1.1 2002/07/14 13:14:38 murrayc Exp $ -*- c++ -*-
+//$Id: server.h 449 2005-11-16 20:22:00Z  $ -*- c++ -*-
 
 /* gtkmm example Copyright (C) 2002 gtkmm development team
  *
@@ -30,7 +30,7 @@ public:
   virtual void do_something();
 
   //signal accessor:
-  typedef SigC::Signal2<void, bool, int> type_signal_something;
+  typedef sigc::signal<void, bool, int> type_signal_something;
   type_signal_something signal_something();
 
 protected:
